@@ -88,8 +88,8 @@ def directional_point_cloud(input_array: np.array,
         Direction of semivariogram, values from 0 to 360 degrees:
         - 0 or 180: is E-W,
         - 90 or 270 is N-S,
-        - 45 or 225 is NW-SE,
-        - 135 or 315 is NE-SW.
+        - 45 or 225 is NE-SW,
+        - 135 or 315 is NW-SE.
 
     tolerance : float, default=1
                 Value in range (0-1] to calculate semi-minor axis length of the search area. If tolerance is close
@@ -144,7 +144,7 @@ def directional_point_cloud(input_array: np.array,
 def build_variogram_point_cloud(input_array: np.array,
                                 step_size: float,
                                 max_range: float,
-                                direction=0.0,
+                                direction=None,
                                 tolerance=1.0) -> dict:
     """
     Function calculates lagged variogram point cloud. Variogram is calculated as a squared difference of each point
@@ -164,12 +164,12 @@ def build_variogram_point_cloud(input_array: np.array,
     weights : numpy array or None, optional, default=None
         Weights assigned to points, index of weight must be the same as index of point.
 
-    direction : float (in range [0, 360]), default=0
+    direction : float (in range [0, 360]), default=None
         Direction of semivariogram, values from 0 to 360 degrees:
         - 0 or 180: is E-W,
         - 90 or 270 is N-S,
-        - 45 or 225 is NW-SE,
-        - 135 or 315 is NE-SW.
+        - 45 or 225 is NE-SW,
+        - 135 or 315 is NW-SE.
 
     tolerance : float (in range [0, 1]), optional, default=1
         If ``tolerance`` is 0 then points must be placed at a single line with the beginning in the origin of
@@ -204,7 +204,7 @@ def build_variogram_point_cloud(input_array: np.array,
     validate_tolerance(tolerance)
     # END:VALIDATION
 
-    if tolerance == 1:
+    if direction is None:
         return omnidirectional_point_cloud(input_array, step_size, max_range)
     else:
         return directional_point_cloud(input_array, step_size, max_range, direction, tolerance)
@@ -228,13 +228,13 @@ class VariogramCloud:
     weights : numpy array or None, optional, default=None
         Weights assigned to points, index of weight must be the same as index of point.
 
-    direction : float (in range [0, 360]), optional, default=0
+    direction : float (in range [0, 360]), optional, default=None
         Direction of semivariogram, values from 0 to 360 degrees:
 
         - 0 or 180: is E-W,
         - 90 or 270 is N-S,
-        - 45 or 225 is NW-SE,
-        - 135 or 315 is NE-SW.
+        - 45 or 225 is NE-SW,
+        - 135 or 315 is NW-SE.
 
     tolerance : float (in range [0, 1]), optional, default=1
         If ``tolerance`` is 0 then points must be placed at a single line with the beginning in the origin of
